@@ -18,21 +18,21 @@ extern "C" {
  *
  * the version string like "1.2.3"
  */
-#define LIBXSLT_DOTTED_VERSION "1.0.23"
+#define LIBXSLT_DOTTED_VERSION "1.0.24"
 
 /**
  * LIBXSLT_VERSION:
  *
  * the version number: 1.2.3 value is 1002003
  */
-#define LIBXSLT_VERSION 10023
+#define LIBXSLT_VERSION 10024
 
 /**
  * LIBXSLT_VERSION_STRING:
  *
  * the version number string, 1.2.3 value is "1002003"
  */
-#define LIBXSLT_VERSION_STRING "10023"
+#define LIBXSLT_VERSION_STRING "10024"
 
 /**
  * WITH_XSLT_DEBUG:
@@ -76,6 +76,11 @@ extern "C" {
 #if 0
 #define XSLT_NEED_TRIO
 #endif
+#ifdef __VMS
+#ifndef XSLT_NEED_TRIO
+#define XSLT_NEED_TRIO
+#endif
+#endif
 
 /**
  * WITH_XSLT_DEBUGGER:
